import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';

export class Report {
  public sus: Array<any>;
  public not_sus: Array<any>;
}

const reportObservable = new Observable<Report> ((observer) => {

  observer.next(
    new Report()
  );

  observer.complete();
});

@Injectable()
export class ReportService {
  getReports(granularity: string, startDate: Date, endDate: Date): Observable<Report> {
    return reportObservable;
  }
}

@Injectable()
export class MockReportService implements ReportService {
  apiRoot:string = 'http://pinsisdev.c3sl.ufpr.br:3000/api/data/';
  apiPeriod: string;
  report: Report;

  constructor(private http: HttpClient) {}

  getReports(granularity: string, startDate: Date, endDate: Date): Observable<Report> {

    switch(granularity) {
      case 'Anual':
      case 'Mensal':
        this.apiPeriod = 'agentusesmonth';
        break;
      case 'Diário':
        this.apiPeriod = 'agentusesday';
        break;
    }

    startDate = new Date(startDate);
    endDate = new Date(endDate);

    let d1: number = startDate.getDate();
    let m1: number = startDate.getMonth() + 1;
    let y1: number = startDate.getFullYear();

    let d2: number = endDate.getDate();
    let m2: number = endDate.getMonth() + 1;
    let y2: number = endDate.getFullYear();

    return this.http
               .get<Report>
               (this.apiRoot + this.apiPeriod +
                '?y1=' + y1 + '&m1=' + m1 + '&d1=' + d1 +
                '&y2=' + y2 + '&m2=' + m2 + '&d2=' + d2
               );
  }
}

@Injectable()
export class WebserviceReportService implements ReportService {
  apiRoot:string = 'http://pinsis.c3sl.ufpr.br:3000/api/data/';
  apiPeriod: string;
  report: Report;

  constructor(private http: HttpClient) {}

  getReports(granularity: string, startDate: Date, endDate: Date): Observable<Report> {

    switch(granularity) {
      case 'Anual':
      case 'Mensal':
        this.apiPeriod = 'agentusesmonth';
        break;
      case 'Diário':
        this.apiPeriod = 'agentusesday';
        break;
    }

    startDate = new Date(startDate);
    endDate = new Date(endDate);

    let d1: number = startDate.getDate();
    let m1: number = startDate.getMonth() + 1;
    let y1: number = startDate.getFullYear();

    let d2: number = endDate.getDate();
    let m2: number = endDate.getMonth() + 1;
    let y2: number = endDate.getFullYear();

    return this.http
               .get<Report>
               (this.apiRoot + this.apiPeriod +
                '?y1=' + y1 + '&m1=' + m1 + '&d1=' + d1 +
                '&y2=' + y2 + '&m2=' + m2 + '&d2=' + d2
               );
  }
}